Summarized the Classic gamma regression for joint modelling of mean and shape parameters.
# S3 method for Gammareg
summary(object, ...)Call
Coefficients
object of class matrix with the estimated covariances of beta.
object of class matrix with the estimated covariances of gamma.
AIC
number of iterations
convergence obtained
an object of class Gammareg
not used.
Martha Corrales martha.corrales@usa.edu.co Edilberto Cepeda-Cuervo ecepedac@unal.edu.co
1. Cepeda-Cuervo, E. (2001). Modelagem da variabilidade em modelos lineares generalizados. Unpublished Ph.D. tesis. Instituto de Matemáticas. Universidade Federal do Río do Janeiro. //http://www.docentes.unal.edu.co/ecepedac/docs/MODELAGEM20DA20VARIABILIDADE.pdf. http://www.bdigital.unal.edu.co/9394/. 2. McCullagh, P. and Nelder, N.A. (1989). Generalized Linear Models. Second Edition. Chapman and Hall.